// PIC16F1827 Configuration Bit Settings

// 'C' source line config statements

#include <xc.h>

// #pragma config statements should precede project file includes.
// Use project enums instead of #define for ON and OFF.

// CONFIG1
#pragma config FOSC = INTOSC    // Oscillator Selection (INTOSC oscillator: I/O function on CLKIN pin)
#pragma config WDTE = OFF       // Watchdog Timer Enable (WDT disabled)
#pragma config PWRTE = ON       // Power-up Timer Enable (PWRT enabled)
#pragma config MCLRE = OFF      // MCLR Pin Function Select (MCLR/VPP pin function is digital input)
#pragma config CP = OFF         // Flash Program Memory Code Protection (Program memory code protection is disabled)
#pragma config CPD = OFF        // Data Memory Code Protection (Data memory code protection is disabled)
#pragma config BOREN = ON       // Brown-out Reset Enable (Brown-out Reset enabled)
#pragma config CLKOUTEN = OFF   // Clock Out Enable (CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin)
#pragma config IESO = OFF       // Internal/External Switchover (Internal/External Switchover mode is disabled)
#pragma config FCMEN = OFF      // Fail-Safe Clock Monitor Enable (Fail-Safe Clock Monitor is disabled)

// CONFIG2
#pragma config WRT = OFF        // Flash Memory Self-Write Protection (Write protection off)
#pragma config PLLEN = OFF      // PLL Enable (4x PLL disabled)
#pragma config STVREN = ON      // Stack Overflow/Underflow Reset Enable (Stack Overflow or Underflow will cause a Reset)
#pragma config BORV = LO        // Brown-out Reset Voltage Selection (Brown-out Reset Voltage (Vbor), low trip point selected.)
#pragma config LVP = OFF        // Low-Voltage Programming Enable (High-voltage on MCLR/VPP must be used for programming)

void tmrcnt();

bit secflg;//１秒経過お知らせ用
unsigned char seccnt;//１秒カウンタ

//割り込み処理
void interrupt intr(void) {
    T0IF = 0;//TMR0割り込みクリア
    tmrcnt();//１秒カウント処理へ
}

//１秒カウント処理
void tmrcnt(void){
    seccnt--;//割り込みが掛かる度に１つ減らす
    if (seccnt == 0){//０になれば１秒経過したことになる
        seccnt = 30;//8000000/4/256/256 = 30.5
        secflg = 1;//1秒経過したよ
    }
}

//メイン処理
main(){

    OSCCON = 0b01110010;//内部クロック８MHz
    ANSELA = 0b00000000;//全てデジタルI/O
    ANSELB = 0b00000000;//全てデジタルI/O
    TRISA  = 0b00000000;//全て出力(RA5は入力のみ)
    TRISB  = 0b00000000;//全て出力

    GIE = 1;//全体割り込み許可
    T0IE = 1;//TMR0割り込み許可
    OPTION_REG = 0b10000111;//プリスケーラ:256
    TMR0 = 0x00;//256数える

    //１秒毎にLEDを点滅
    seccnt = 30;//8000000/4/256/256 = 30.5
                //１秒間に8000000クロック発生する設定にしてある
                //４つ数えるごとに１つプリスケーラに送られる
                //プリスケーラは256回数えるとタイマーに１つ送る
                //タイマーはそれを256回数えると割り込みを発生させる
                //以上を30.5回行うと8000000数えたことになる
    secflg = 0;//１秒経過すると１

    while(1){
        if(secflg){//もし１秒経過してたら
            secflg = 0;//次の１秒までは０のまま
            RA0 ^= 1;//RA3のLEDを点滅(ビットを反転)
        }
    }
}